@@ -1,5 +1,5 @@
-# 4C3HOH1: XML::Tidy.pm by PipStuart<Pip@CPAN.Org> to tidy XML documents as parsed XML::XPath objects;
-package XML::Tidy;
+# 4C3HOH1:   XML::Tidy.pm by Pip Stuart <Pip@CPAN.Org> to tidy XML documents as parsed XML::XPath objects;
+package      XML::Tidy;
 use strict;use warnings;
 require      XML::XPath;
 use base qw( XML::XPath Exporter );
@@ -8,7 +8,7 @@ use Carp;
 use Exporter;
 use Math::BaseCnv qw(:b64);
 use XML::XPath::XMLParser;
-our $VERSION     = '1.14';our $d8VS='G6JMERCY';
+our $VERSION     = '1.16';our $d8VS='G6LM4EST';
 @EXPORT = qw(
     UNKNOWN_NODE
     ELEMENT_NODE
@@ -779,8 +779,8 @@ XML::Tidy - tidy indenting of XML documents
 
 =head1 VERSION
 
-This documentation refers to version 1.14 of XML::Tidy, which was released on
-Sun Jun 19 14:27:12:34 -0500 2016.
+This documentation refers to version 1.16 of XML::Tidy, which was released on
+Tue Jun 21 04:14:28:29 -0500 2016.
 
 =head1 SYNOPSIS
 
@@ -800,18 +800,18 @@ Sun Jun 19 14:27:12:34 -0500 2016.
 This module creates XML document objects (with inheritance from
 L<XML::XPath>) to tidy mixed-content (i.e., non-data) text node
 indenting. There are also some other handy member functions to
-compress && expand your XML document object (into either a
+compress and expand your XML document object (into either a
 compact XML representation or a binary one).
 
-=head1 2DU
+=head1 TODO
 
 =over 2
 
-=item - maybe add support for binary char && short ints && single-precision floats
+=item - maybe add to bcompress support for binary char, wide UTF-8, short ints, and single or quad-precision floats
 
-=item - maybe store recurring patterns of node index sets in new array that can be indexed themself
+=item - maybe store in compress recurring patterns of node index sets in a new array that can be indexed itself
 
-=item - fix reload() from messing up unicode escaped &XYZ; components like Copyright &#xA9; && Registered &#xAE;
+=item - fix reload() from messing up Unicode escaped &XYZ; components like Copyright &#xA9; and Registered &#xAE;
 
 =item -     What else does Tidy need?
 
@@ -842,16 +842,16 @@ which impact the tree node hierarchy because L<XML::XPath>'s find()
 member preserves state information which can get out-of-sync.
 
 reload() is probably rarely useful by itself but it is needed by
-strip() && prune() so it is exposed as a method in case it comes in
+strip() and prune() so it is exposed as a method in case it comes in
 handy for other uses.
 
 =head2 strip()
 
 The strip() member function searches the Tidy object for all
-mixed-content (i.e., non-data) text nodes && empties them out.
+mixed-content (i.e., non-data) text nodes and empties them out.
 This will basically unformat any markup indenting.
 
-strip() is used by compress() && tidy() but it is exposed because it
+strip() is used by compress() and tidy() but it is exposed because it
 could be worthwhile by itself.
 
 =head2 tidy()
@@ -878,15 +878,15 @@ NOTE: tidy() disturbs some XML escapes in whatever ways L<XML::XPath>
 does. It has been brought to my attention that these modules also strip
 CDATA tags from XML files / data they operate on. Even though
 CDATA tags don't seem very common, I wish they could work smoothly too.
-Hopefully the vast majority of files will work fine && support for
+Hopefully the vast majority of files will work fine and support for
 other types can be added later.
 
 =head2 compress()
 
 The compress() member function calls strip() on the Tidy object
 then creates an encoded comment which contains the names of elements
-&& attributes as they occurred in the original document. Their
-respective element && attribute names are replaced with just the
+and attributes as they occurred in the original document. Their
+respective element and attribute names are replaced with just the
 appropriate index throughout the document.
 
 compress() can accept a parameter describing which node types to
@@ -901,14 +901,14 @@ include as in the following mapping:
   c = comment    nodes *EXPERIMENTAL*
   n = namespace  nodes *not-yet-implemented*
 
-Attribute values ('v') && text nodes ('t') both seem to work fine
+Attribute values ('v') and text nodes ('t') both seem to work fine
 with current tokenization. I've still labeled them EXPERIMENTAL
 because they seem more likely to cause problems than valid element
 or attribute key names. I have some bugs in the comment node
 compression which I haven't been able to find yet so that one should
 be avoided for now. Since these three node types ('vtc')
 all require tokenization, they are not included in default compression
-('ea'). An example call which includes values && text would be:
+('ea'). An example call which includes values and text would be:
 
   $tidy_obj->compress('eavt');
 
@@ -920,7 +920,7 @@ expand() performs the opposite conversion.
 =head2 expand()
 
 The expand() member function reads any XML::Tidy::compress comments
-from the Tidy object && uses them to reconstruct the document
+from the Tidy object and uses them to reconstruct the document
 that was passed to compress().
 
 =head2 bcompress('BinaryOutputFilename.xtb')
@@ -951,9 +951,9 @@ attribute or a processing instruction, the next index is read (without
 another accompanying type value) in order to complete the data fields
 required by those node types.
 
-NOTE: Please bear in mind that the encoding of binary integers && floats
+NOTE: Please bear in mind that the encoding of binary integers and floats
 only works properly if the values are not surrounded by spaces or other
-delimiters && each is contained in its own single node. This is
+delimiters and each is contained in its own single node. This is
 necessary to enable thorough reconstruction of whitespace from the
 original document. I recommend storing every numerical value as an
 isolated attribute value or text node without any surrounding whitespace.
@@ -987,7 +987,7 @@ object constructor like new() so it can be called like:
 =head2 prune()
 
 The prune() member function takes an XPath location to remove (along
-with all attributes && child nodes) from the Tidy object. For
+with all attributes and child nodes) from the Tidy object. For
 example, to remove all comments:
 
   $tidy_obj->prune('//comment()');
@@ -1014,7 +1014,7 @@ Tidy object's root. Only the first matching element is written.
 =head2 toString()
 
 The toString() member function is almost identical to write() except
-that it takes no parameters && simply returns the equivalent XML
+that it takes no parameters and simply returns the equivalent XML
 string as a scalar. It is a little weird because normally only
 L<XML::XPath::Node> objects have a toString() member but I figure it
 makes sense to extend the same syntax to the parent object as well
@@ -1102,15 +1102,27 @@ Revision history for Perl extension XML::Tidy:
 
 =over 2
 
+=item - 1.16 G6LM4EST  Tue Jun 21 04:14:28:29 -0500 2016
+
+* stopped using my old fragile package generation and manually updated all distribution files (though L<Dist::Zilla> should let me generate much again)
+
+* updated license to GPLv3+
+
+* fixed 00pod.t and 01podc.t to eval the Test modules from issue and patch: HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=85592 (Thanks again MichielB.)
+
+* replaced all old '&&' with 'and' in POD
+
 =item - 1.14 G6JMERCY  Sun Jun 19 14:27:12:34 -0500 2016
 
-* removed Unicode from POD but added encoding utf8 anyway to pass tests
+* separated old PT from VERSION to fix non-numeric issue: HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=56073 (Thanks to Slaven.)
+
+* removed Unicode from POD but added encoding utf8 anyway to pass tests and resolve issues: HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=92434 and HTTPS://RT.CPAN.Org/Public/Bug/Display.html?id=85592 (Thanks to Sudhanshu and MichielB.)
 
 =item - 1.12.B55J2qn  Thu May  5 19:02:52:49 2011
 
 * made "1.0" float binarize as float again, rather than just "1" int
 
-* cleaned up POD && fixed EXPORTED CONSTANTS heads blocking together
+* cleaned up POD and fixed EXPORTED CONSTANTS heads blocking together
 
 =item - 1.10.B52FpLx  Mon May  2 15:51:21:59 2011
 
@@ -1140,7 +1152,7 @@ Revision history for Perl extension XML::Tidy:
 
 * made "1.0" float binarize as just "1" int
 
-* made ints signed && bounds checked
+* made ints signed and bounds checked
 
 * added new('binary' => 'BinFilename.xtb') option
 
@@ -1148,15 +1160,15 @@ Revision history for Perl extension XML::Tidy:
 
 * fixed tidy() processing instruction stripping problem
 
-* added support for binary ints && floats in bcompress()
+* added support for binary ints and floats in bcompress()
 
-* tightened up binary format && added pod
+* tightened up binary format and added pod
 
 =item - 1.2.54HDR1G  Sun Apr 17 13:27:01:16 2005
 
-* added bcompress() && bexpand()
+* added bcompress() and bexpand()
 
-* added  compress() &&  expand()
+* added  compress() and  expand()
 
 * added toString()
 
@@ -1200,7 +1212,7 @@ From the command shell, please run:
 
   `perl -MCPAN -e "install XML::Tidy"`
 
-or uncompress the package && run the standard:
+or uncompress the package and run the standard:
 
   `perl Makefile.PL; make; make test; make install`
 
@@ -1210,20 +1222,22 @@ XML::Tidy requires:
 
 L<Carp>                  to allow errors to croak() from calling sub
 
-L<XML::XPath>            to use XPath statements to query && update XML
+L<XML::XPath>            to use XPath statements to query and update XML
 
 L<XML::XPath::XMLParser> to parse XML documents into XPath objects
 
-L<Math::BaseCnv>         to handle base-64 indexing for compress() && expand()
+L<Math::BaseCnv>         to handle base-64 indexing for compress() and expand()
 
 =head1 LICENSE
 
 Most source code should be Free!
-  Code I have lawful authority over is && shall be!
+  Code I have lawful authority over is and shall be!
 Copyright: (c) 2004-2016, Pip Stuart.
-Copyleft :  This software is licensed under the GNU General Public
-  License (version 3). Please consult the Free Software Foundation
-  (HTTP://FSF.Org) for important information about your freedom.
+Copyleft :  This software is licensed under the GNU General Public License
+  (version 3 or later). Please consult HTTP://GNU.Org/licenses/gpl-3.0.txt
+  for important information about your freedom. This is Free Software: you
+  are free to change and redistribute it. There is NO WARRANTY, to the
+  extent permitted by law. See HTTP://FSF.Org for further information.
 
 =head1 AUTHOR
 
